@@ -9,16 +9,16 @@ class Command(BaseCommand):
     help = "Loads the dumps into the database."
 
     def add_arguments(self, parser):
-        parser.add_argument("args", metavar="dump", nargs="+", help="Dumps.")
         parser.add_argument(
             "--ignorenonexistent",
             action="store_true",
             dest="ignorenonexistent",
             help=(
                 "Ignore entries in the serialized data for fields that do not"
-                " currently exist on the model.",
+                " currently exist on the model."
             ),
         )
+        parser.add_argument("args", metavar="dump", nargs="+", help="Dumps.")
 
     def handle(self, *dumps, **options):
         for dump in dumps:
